# DevicesInLan [![PyPI - Downloads](https://img.shields.io/pypi/dm/devicesinlan?label=Pypi%20downloads)](https://pypi.org/project/devicesinlan/) [![Github - Downloads](https://shields.io/github/downloads/turulomio/devicesinlan/total?label=Github%20downloads )](https://github.com/turulomio/devicesinlan/)

Snapshots
=========

![Snapshot](https://raw.githubusercontent.com/turulomio/devicesinlan/qt5/doc/devicesinlan_snapshots_01.png)

Links
=====
  
Project web page:
  * https://github.com/turulomio/devicesinlan/

App statistics
  * https://devicesinlan.sourceforge.net/php/devicesinlan_statistics.php

Install in Linux
================
If you use Gentoo you can find a ebuild in https://github.com/turulomio/myportage/tree/master/net-analyzer/devicesinlan

If you use other distribution compatible con pip: `pip install devicesinlan`

Install in Windows as a python module
=====================================
You need to install Python from https://www.python.org and add it to the PATH

You must open a console with Administrator privileges and type:

`pip install devicesinlan`

If you want to create a Desktop shortcut to launch Xulpymoney you must write in a console:

`devicesinlan_shortcut.exe`

- Fix remote version bug